@@ -107,6 +107,21 @@ class SplitCommandBase(Base, ABC):
             name=name, context=self.context, event_service=self.event_service
         )
 
+    def _user_has_permission(self, permission: str) -> bool:
+        """
+        Check if the currently logged in user has the specified permission,
+        and return the result.
+        """
+
+        # Command instances do not have `user_info` when called from
+        # consumers.
+        # Once consumers have the full user_info, this entire condition should
+        # be removed:
+        if not hasattr(self.cmd, "user_info"):
+            return True
+
+        return self.cmd.user_info.permissions.get(permission, False)
+
 
 class SplitQueryBase(Base, ABC):
     """
