@@ -2,7 +2,7 @@
 #
 # SPDX-License-Identifier: EUPL-1.2
 
-import statsd
+import statsd  # type: ignore
 import threading
 from .. import Base
 from ..config.parser import ApacheConfigParser, ConfigParserBase
@@ -11,7 +11,7 @@ from ..exceptions import ConfigurationConflict
 from collections import namedtuple
 from copy import copy
 from redis import StrictRedis
-from typing import Callable, Dict, Mapping, Optional, Type
+from typing import Callable, Dict, Mapping, Optional, Type, cast
 
 CONFIG_STORE_MAP: Mapping[str, Callable] = {
     "file": FileStore,
@@ -192,12 +192,19 @@ class InfrastructureFactory(Base):
         :rtype: object
         """
         config = self.get_config(context=context)
-        with self.statsd.get_timer("get_infrastructure").time(
-            infrastructure_name
-        ):
+
+        timer = cast(
+            statsd.Timer,
+            self.statsd.get_timer(
+                f"get_infrastructure,name={infrastructure_name}"
+            ),
+        )
+
+        with timer.time():
             infra = self._registered_infrastructure[infrastructure_name](
                 config=config
             )
+
         return infra
 
     def flush_local_storage(self):
@@ -207,16 +214,21 @@ class InfrastructureFactory(Base):
         instances might not have the `.clean_up(infrastructure)` method.
         """
         for infra_key, infra in self._local_storage.infra.items():
-            try:
-                with self.statsd.get_timer(
-                    f"{infra_key.infrastructure_name}"
-                ).time("clean_up"):
+            timer = cast(
+                statsd.Timer,
+                self.statsd.get_timer(
+                    f"cleanup,name={infra_key.infrastructure_name}"
+                ),
+            )
+
+            with timer.time():
+                try:
                     self._registered_infrastructure[
                         infra_key.infrastructure_name
                     ].clean_up(infra)
-            except AttributeError:
-                # Infrastructure does not have clean_up method implemented.
-                pass
+                except AttributeError:
+                    # Infrastructure does not have clean_up method implemented.
+                    pass
         self._local_storage.infra = {}
         return
 
@@ -225,5 +237,5 @@ class LocalInfrastructureStorage(threading.local):
     """Thread local storage for infrastructure."""
 
     def __init__(self):
-        """Initilize the local storage for infrastructure with infra dict."""
+        """Initialize the local storage for infrastructure with infra dict."""
         self.infra = {}
